Index: c/src/libchip/serial/mc68681.h
===================================================================
--- c/src/libchip/serial/mc68681.h	(revision 64ecfc17b755de77ef7dc17d43408d4bffed69eb)
+++ c/src/libchip/serial/mc68681.h	(revision 93531e9b08b2c641abc4bf5e53c5ebcd754c7d55)
@@ -11,4 +11,6 @@
 #ifndef _MC68681_H_
 #define _MC68681_H_
+
+#include <rtems/termiostypes.h>
 
 #ifdef __cplusplus
Index: cpukit/libcsupport/include/rtems/termiostypes.h
===================================================================
--- cpukit/libcsupport/include/rtems/termiostypes.h	(revision 64ecfc17b755de77ef7dc17d43408d4bffed69eb)
+++ cpukit/libcsupport/include/rtems/termiostypes.h	(revision 93531e9b08b2c641abc4bf5e53c5ebcd754c7d55)
@@ -21,4 +21,5 @@
 #include <rtems/assoc.h>
 #include <rtems/chain.h>
+#include <sys/ioccom.h>
 #include <stdint.h>
 #include <termios.h>
@@ -574,4 +575,12 @@
 );
 
+#define RTEMS_IO_SNDWAKEUP _IOW('t', 11, struct ttywakeup ) /* send tty wakeup */
+#define RTEMS_IO_RCVWAKEUP _IOW('t', 12, struct ttywakeup ) /* recv tty wakeup */
+
+#define	OLCUC		0x00000100	/* map lower case to upper case on output */
+#define	IUCLC		0x00004000	/* map upper case to lower case on input */
+
+#define RTEMS_TERMIOS_NUMBER_BAUD_RATES 25
+
 #ifdef __cplusplus
 }
Index: cpukit/libcsupport/include/sys/_termios.h
===================================================================
--- cpukit/libcsupport/include/sys/_termios.h	(revision 64ecfc17b755de77ef7dc17d43408d4bffed69eb)
+++ cpukit/libcsupport/include/sys/_termios.h	(revision 93531e9b08b2c641abc4bf5e53c5ebcd754c7d55)
@@ -96,7 +96,4 @@
 #define	IMAXBEL		0x00002000	/* ring bell on input queue full */
 #endif  /*_POSIX_SOURCE */
-#ifdef __rtems__
-#define	IUCLC		0x00004000	/* map upper case to lower case on input */
-#endif /* __rtems__ */
 /*
  * Output flags - software output processing
@@ -119,29 +116,8 @@
 #define	    TAB2	    0x00000008
 #define	    TAB3	    0x0000000C	    /* expand tabs to spaces */
-#define	    XTABS	    0x0000000C
 #define	ONOEOT		0x00000010	/* discard EOT's (^D) on output) */
 #define	OCRNL		0x00000020	/* map CR to NL on output */
 #define	ONOCR		0x00000040	/* no CR output at column 0 */
 #define	ONLRET		0x00000080	/* NL performs CR function */
-#define	OLCUC		0x00000100	/* map lower case to upper case on output */
-#define	OFILL		0x00000200	/* send fill characters for a delay, rather than using a timed delay */
-#define	OFDEL		0x00000400	/* fill character is ASCII DEL (0177). if unset, fill character is ASCII NUL ('\0') */
-#define	NLDLY		0x00000800	/* newline delay mask */
-#define	    NL0	    0x00000000
-#define	    NL1	    0x00000800
-#define	CRDLY		0x00003000	/* carriage return delay mask */
-#define	    CR0	    0x00000000
-#define	    CR1	    0x00001000
-#define	    CR2	    0x00002000
-#define	    CR3	    0x00003000
-#define	BSDLY		0x00004000	/* Backspace delay mask */
-#define	    BS0	    0x00000000
-#define	    BS1	    0x00004000
-#define	VTDLY		0x00008000	/* Vertical tab delay mask */
-#define	    VT0	    0x00000000
-#define	    VT1	    0x00008000
-#define	FFDLY		0x00010000	/* Form feed delay mask */
-#define	    FF0	    0x00000000
-#define	    FF1	    0x00010000
 #endif /* __rtems__ */
 #endif  /*_POSIX_SOURCE */
@@ -244,8 +220,4 @@
 #endif  /* !_POSIX_SOURCE */
 
-#ifdef __rtems__
-#define RTEMS_TERMIOS_NUMBER_BAUD_RATES 25
-#endif /* __rtems__ */
-
 typedef unsigned int  tcflag_t;
 typedef unsigned char	cc_t;
Index: cpukit/libcsupport/include/sys/ttycom.h
===================================================================
--- cpukit/libcsupport/include/sys/ttycom.h	(revision 64ecfc17b755de77ef7dc17d43408d4bffed69eb)
+++ cpukit/libcsupport/include/sys/ttycom.h	(revision 93531e9b08b2c641abc4bf5e53c5ebcd754c7d55)
@@ -61,8 +61,4 @@
 						/* 8-10 compat */
 						/* 11-12 unused */
-#ifdef __rtems__
-#define RTEMS_IO_SNDWAKEUP _IOW('t', 11, struct ttywakeup ) /* send tty wakeup */
-#define RTEMS_IO_RCVWAKEUP _IOW('t', 12, struct ttywakeup ) /* recv tty wakeup */
-#endif /* __rtems__ */
 #define TIOCEXCL   _IO('t', 13)   /* set exclusive use of tty */
 #define	TIOCNXCL	 _IO('t', 14)		/* reset exclusive use of tty */
Index: cpukit/libcsupport/src/termios.c
===================================================================
--- cpukit/libcsupport/src/termios.c	(revision 64ecfc17b755de77ef7dc17d43408d4bffed69eb)
+++ cpukit/libcsupport/src/termios.c	(revision 93531e9b08b2c641abc4bf5e53c5ebcd754c7d55)
@@ -578,5 +578,5 @@
      */
     tty->termios.c_iflag = BRKINT | ICRNL | IXON | IMAXBEL;
-    tty->termios.c_oflag = OPOST | ONLCR | XTABS;
+    tty->termios.c_oflag = OPOST | ONLCR | OXTABS;
     tty->termios.c_cflag = CS8 | CREAD | CLOCAL;
     tty->termios.c_lflag =
@@ -1189,5 +1189,5 @@
     case '\t':
       columnAdj = 8 - (oldColumn & 7);
-      if ((tty->termios.c_oflag & TABDLY) == XTABS) {
+      if ((tty->termios.c_oflag & TABDLY) == OXTABS) {
         int i;
 
Index: testsuites/libtests/termios/init.c
===================================================================
--- testsuites/libtests/termios/init.c	(revision 64ecfc17b755de77ef7dc17d43408d4bffed69eb)
+++ testsuites/libtests/termios/init.c	(revision 93531e9b08b2c641abc4bf5e53c5ebcd754c7d55)
@@ -28,4 +28,5 @@
 
 #include <rtems/shell.h>
+#include <rtems/termiostypes.h>
 
 #include <stdio.h>
@@ -132,85 +133,4 @@
     printf( "ONLRET " );
 
-  if( tp->c_oflag & OFILL )
-    printf( "OFILL " );
-
-  if( tp->c_oflag & OFDEL )
-    printf( "OFDEL " );
-
-  switch( tp->c_oflag & NLDLY ) {
-    case NL0:
-      printf( "NL0 " );
-      break;
-
-    case NL1:
-      printf( "NL1 " );
-      break;
-  }
-
-  switch( tp->c_oflag & CRDLY ) {
-    case CR0:
-      printf( "CR0 " );
-      break;
-
-    case CR1:
-      printf( "CR1 " );
-      break;
-
-    case CR2:
-      printf( "CR2 " );
-      break;
-
-    case CR3:
-      printf( "CR3 " );
-      break;
-  }
-
-  switch( tp->c_oflag & TABDLY ) {
-    case TAB0:
-      printf( "TAB0 " );
-      break;
-
-    case TAB1:
-      printf( "TAB1 " );
-      break;
-
-    case TAB2:
-      printf( "TAB2 " );
-      break;
-
-    case TAB3:
-      printf( "TAB3 " );
-      break;
-  }
-
-  switch( tp->c_oflag & BSDLY ) {
-    case BS0:
-      printf( "BS0 " );
-      break;
-
-    case BS1:
-      printf( "BS1 " );
-      break;
-  }
-
-  switch( tp->c_oflag & VTDLY ) {
-    case VT0:
-      printf( "VT0 " );
-      break;
-
-    case VT1:
-      printf( "VT1 " );
-      break;
-  }
-
-  switch( tp->c_oflag & FFDLY ) {
-    case FF0:
-      printf( "FF0" );
-      break;
-
-    case FF1:
-      printf( "FF1" );
-      break;
-  }
   printf( "\n" );
 }
Index: testsuites/libtests/termios03/init.c
===================================================================
--- testsuites/libtests/termios03/init.c	(revision 64ecfc17b755de77ef7dc17d43408d4bffed69eb)
+++ testsuites/libtests/termios03/init.c	(revision 93531e9b08b2c641abc4bf5e53c5ebcd754c7d55)
@@ -22,4 +22,5 @@
 #include <termios.h>
 #include <rtems/dumpbuf.h>
+#include <rtems/termiostypes.h>
 
 const char rtems_test_name[] = "TERMIOS 3";
Index: testsuites/libtests/termios05/init.c
===================================================================
--- testsuites/libtests/termios05/init.c	(revision 64ecfc17b755de77ef7dc17d43408d4bffed69eb)
+++ testsuites/libtests/termios05/init.c	(revision 93531e9b08b2c641abc4bf5e53c5ebcd754c7d55)
@@ -22,4 +22,5 @@
 #include <termios.h>
 #include <rtems/dumpbuf.h>
+#include <rtems/termiostypes.h>
 
 const char rtems_test_name[] = "TERMIOS 5";
Index: testsuites/libtests/termios09/init.c
===================================================================
--- testsuites/libtests/termios09/init.c	(revision 64ecfc17b755de77ef7dc17d43408d4bffed69eb)
+++ testsuites/libtests/termios09/init.c	(revision 93531e9b08b2c641abc4bf5e53c5ebcd754c7d55)
@@ -849,5 +849,5 @@
 static void test_xtabs(test_context *ctx)
 {
-  tcflag_t oflags = OPOST | XTABS;
+  tcflag_t oflags = OPOST | OXTABS;
   size_t i;
 
@@ -953,5 +953,5 @@
 static void test_write(test_context *ctx)
 {
-  tcflag_t oflags = OPOST | ONLCR | XTABS;
+  tcflag_t oflags = OPOST | ONLCR | OXTABS;
   rtems_status_code sc;
   size_t i = INTERRUPT;
@@ -1032,5 +1032,5 @@
   rtems_test_assert(memcmp(dev->output_buf, buf, OUTPUT_BUFFER_SIZE) == 0);
 
   /* Ensure that XTABS output expansion is taken into account */
 
   dev->tty->column = 0;
@@ -1032,5 +1032,5 @@
   rtems_test_assert(memcmp(dev->output_buf, buf, OUTPUT_BUFFER_SIZE) == 0);
 
-  /* Ensure that XTABS output expansion is taken into account */
+  /* Ensure that OXTABS output expansion is taken into account */
 
   dev->tty->column = 0;
